<?php

namespace EasyContent\WordPress\Controllers\Actions\Main;

use EasyContent\WordPress\Api\Connector;
use EasyContent\WordPress\Controllers\Actions\BaseAction;
use EasyContent\WordPress\Forms\Entities\ApiKeys;
use EasyContent\WordPress\Forms\Entities\ServerConnectionResponse;
use EasyContent\WordPress\Plugin;
use EasyContent\WordPress\View;
use Symfony\Component\Form\Extension\Core\Type\FormType;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\Extension\Core\Type\UrlType;
use Symfony\Component\HttpFoundation\Request;

class Connection extends BaseAction
{
    public function run(Request $request)
    {
        $plugin = Plugin::getInstance();
        $formBuilder = $plugin->getFormFactory()->createBuilder( FormType::class, new ApiKeys() );

        $form = $formBuilder
            ->add( 'public', TextType::class )
            ->add( 'url', UrlType::class )
            ->getForm();

        $form->handleRequest( $request );

        if ( $form->isSubmitted() && $form->isValid() ) {
            try {
                /** @var ServerConnectionResponse $responseData */
                $responseData = (new Connector())->connectUsingApiKeys( $form->getData() );

                $successMessage = (new View())->render( 'admin/pages/connection/success-message', [
                    'userName' => 0 == wp_get_current_user()->ID ? '' : wp_get_current_user()->display_name,
                    'accountName' => $responseData->getAccountName()
                ] );

                $plugin->noticesManager->addNotice( $successMessage );
            } catch ( \Exception $e ) {
                $plugin->noticesManager->addNotice( $e->getMessage(), 'error' );
            }
        } elseif ( count( $form->getErrors() ) > 0 ) {
            foreach ( $form->getErrors() as $error ) {
                $plugin->noticesManager->addNotice( $error->getMessage(), 'error' );
            }
        }


        return $this->render( 'admin/pages/connection', [
            'formView'    => $form->createView(),
            'isConnected' => $plugin->getSettings()->isPluginConnected,
            'projectName' => $plugin->getMisc()->projectName,
            'accountName' => $plugin->getMisc()->accountName,
            'projectUrl'  => str_replace( '/edit/', '', $plugin->getMisc()->editUrlBase ),
            'referer'     => $plugin->getRefererString()
        ] );
    }
}
