<?php

namespace EasyContent\WordPress\Controllers\Actions\Main;

use EasyContent\WordPress\Controllers\Actions\BaseAction;
use EasyContent\WordPress\Forms\Entities\ImageProcessingSettings;
use EasyContent\WordPress\Plugin;
use Symfony\Component\Form\Extension\Core\Type\CheckboxType;
use Symfony\Component\Form\Extension\Core\Type\FormType;
use Symfony\Component\HttpFoundation\Request;

class ImageProcessing extends BaseAction
{
    public function run(Request $request)
    {
        $plugin = Plugin::getInstance();
        $form = $plugin->getFormFactory()
            ->createBuilder( FormType::class, new ImageProcessingSettings() )
            ->add( 'enableResizing', CheckboxType::class )
            ->add( 'maxWidth' )
            ->add( 'maxHeight' )
            ->add( 'jpgCompressionLevel' )
            ->getForm();

        $form->handleRequest( $request );

        if ( $form->isSubmitted() && $form->isValid() ) {
            $form->getData()->save();

            $message = __( 'Image processing settings were saved successfully', EASYCONTENT_TXTDOMAIN );
            $plugin->noticesManager->addNotice( $message );
        } elseif ( count( $form->getErrors() ) > 0 ) {
            foreach ( $form->getErrors() as $error ) {
                $plugin->noticesManager->addNotice( $error->getMessage(), 'error' );
            }
        }


        return $this->render( 'admin/pages/resize-options', [
            'formView' => $form->createView()
        ] );
    }
}
