<?php

namespace EasyContent\WordPress\Controllers\Actions\Main;

use EasyContent\WordPress\Api\Models\Article;
use EasyContent\WordPress\Controllers\Actions\BaseAction;
use EasyContent\WordPress\Db\Models\WorkflowStage;
use EasyContent\WordPress\Forms\Entities\ArticlesFilter;
use EasyContent\WordPress\Forms\Entities\ImportEntity;
use EasyContent\WordPress\Forms\Handlers\RefreshAllDataFormHandler;
use EasyContent\WordPress\Forms\Types\ArticlesFilterType;
use EasyContent\WordPress\Pages\Import\ArticlesListTable;
use EasyContent\WordPress\Plugin;
use Symfony\Component\Form\Extension\Core\Type\CollectionType;
use Symfony\Component\Form\Extension\Core\Type\FormType;
use Symfony\Component\HttpFoundation\Request;
use EasyContent\WordPress\Db\Models\Article as ArticleDbModel;

class Import extends BaseAction
{
    public function run(Request $request)
    {
        $plugin = Plugin::getInstance();
        $formFactory = $plugin->getFormFactory();


        $importForm = $formFactory
            ->createBuilder( FormType::class, new ImportEntity() )
            ->add( 'newStage' )
            ->add( 'articleIds', CollectionType::class, ['allow_add' => true] )
            ->getForm();

        $location = isset( $_POST['ECImportArticlesForm']['run'] )
            ? sanitize_text_field( $_POST['ECImportArticlesForm']['run'] )
            : null;

        if ( $location ) {
            $newStageId = ! empty( $_POST['ECImportArticlesForm'][$location]['newStage'] )
                ? absint( $_POST['ECImportArticlesForm'][$location]['newStage'] )
                : null;

            $articleIds = isset( $_POST['ECImportArticlesForm']['topic-ids'] )
                ? array_map( 'absint', (array)$_POST['ECImportArticlesForm']['topic-ids'] )
                : [];

            $importForm->submit( [
                'newStage' => $newStageId,
                'articleIds' => $articleIds
            ] );

            if ( $importForm->isSubmitted() && $importForm->isValid() ) {
                if ( $importForm->getData()->process() ) {
                    $n = count( $importForm->getData()->getArticleIds() );
                    $message = "{$n} articles were added successfully!";

                    $plugin->noticesManager->addNotice( $message );
                }
            } elseif ( count( $importForm->getErrors() ) > 0 ) {
                foreach ( $importForm->getErrors() as $error ) {
                    $plugin->noticesManager->addNotice( $error->getMessage(), 'error' );
                }
            }
        }


        ( new RefreshAllDataFormHandler() )->handle();


        $searchForm = $formFactory
            ->createBuilder( ArticlesFilterType::class, new ArticlesFilter() )
            ->getForm()
            ->handleRequest($request);


        $table = new ArticlesListTable( $searchForm );
        $table->prepare_items();

        return $this->render( 'admin/pages/import', [
            'table' => $table,
            'workflowStages' => WorkflowStage::all(),
            'searchFormView' => $searchForm->createView()
        ] );
    }
}
