<?php

use Phinx\Migration\AbstractMigration;
use EasyContent\WordPress\Db\Models;

class Initial extends AbstractMigration
{
    public function change()
    {
        $articlesTable = $this->table( Models\Article::tableName(), [
            'id' => false,
            'primary_key' => ['id']
        ] );

        $articlesTable
            ->addColumn( 'id', 'integer', [
                'null' => false,
                'signed' => false
            ] )
            ->addColumn( 'current_workflow_stage_id', 'integer', [
                'null' => false,
                'signed' => false
            ] )
            ->addColumn( 'category_id', 'integer', [
                'null' => true,
                'signed' => false,
                'default' => 0
            ] )
            ->addColumn( 'topic_name', 'string', [
                'null' => false,
                'limit' => 255
            ] )
            ->addColumn( 'title', 'string', [
                'null' => true,
                'default' => null,
                'limit' => 255
            ] )
            ->addColumn( 'updated', 'integer', [
                'null' => true,
                'signed' => false,
                'default' => 0
            ] )
            ->create();


        $workflowStageTable = $this->table( Models\WorkflowStage::tableName(), [
            'id' => false,
            'primary_key' => ['id']
        ] );

        $workflowStageTable
            ->addColumn( 'id', 'integer', [
                'null' => false,
                'signed' => false
            ] )
            ->addColumn( 'color', 'string', [
                'null' => false,
                'limit' => 6
            ] )
            ->addColumn( 'name', 'string', [
                'null' => false,
                'limit' => 255
            ] )
            ->addColumn( 'is_core', 'integer', [
                'null' => false,
                'signed' => false,
                'default' => 0
            ] )
            ->create();


        $categoryTable = $this->table( Models\Category::tableName(), [
            'id' => false,
            'primary_key' => ['id']
        ] );

        $categoryTable
            ->addColumn( 'id', 'integer', [
                'null' => false,
                'signed' => false
            ] )
            ->addColumn( 'parent_category_id', 'integer', [
                'null' => false,
                'signed' => false,
                'default' => 0
            ] )
            ->addColumn( 'name', 'string', [
                'null' => false,
                'limit' => 255
            ] )
            ->create();


        $junctionTable = $this->table( Models\ArticlePost::tableName() );

        $junctionTable
            ->addColumn( 'article_id', 'integer', [
                'signed' => false,
                'null' => false
            ] )
            ->addColumn( 'post_id', 'integer', [
                'signed' => false,
                'null' => false
            ] )
            ->addColumn( 'sync_time', 'integer', [
                'signed' => false,
                'null' => false
            ] )
            ->addIndex(['article_id', 'post_id'], ['unique' => true])
            ->create();
    }
}
