<?php

namespace EasyContent\WordPress\Db\Models;

use EasyContent\WordPress\Db\BaseModel;

/**
 * @property integer $id
 * @property integer $article_id
 * @property integer $post_id
 * @property integer $sync_time
 */
class ArticlePost extends BaseModel
{
    public static function getFieldNames()
    {
        return ['id', 'article_id', 'post_id', 'sync_time'];
    }


    public static function attach($articleId, $postId)
    {
        return static::insertRow( [
            'article_id' => $articleId,
            'post_id' => $postId,
            'sync_time' => time()
        ] );
    }

    public static function detach($articleId, $postId)
    {
        $wpdb = static::getWpdb();
        $tableName = static::tableName();

        $query = "DELETE FROM `{$tableName}` WHERE `article_id` = %d AND `post_id` = %d;";

        $wpdb->query( $wpdb->prepare( $query, $articleId, $postId ) );
    }


    public static function setSynchronizationTime($articleId, $postId)
    {
        $wpdb = static::getWpdb();
        $tableName = static::tableName();

        $wpdb->update( $tableName, ['sync_time' => time()], ['article_id' => $articleId, 'post_id' => $postId], ['%d'], ['%d', '%d'] );
    }


    public static function getSynchronizationTime($articleId, $postId)
    {
        $wpdb = static::getWpdb();
        $tableName = static::tableName();

        $query = "SELECT `sync_time` FROM `{$tableName}` WHERE `article_id` = %d AND `post_id` = %d LIMIT 1;";

        $result = (int)$wpdb->get_var( $wpdb->prepare( $query, $articleId, $postId ) );

        return $result ?: null;
    }
}
