<?php

namespace EasyContent\WordPress\Forms\Entities;

use EasyContent\WordPress\Plugin;
use Symfony\Component\Validator\Constraints as Assert;

class ImageProcessingSettings
{
    /**
     * @Assert\NotNull
     */
    protected $enableResizing;

    /**
     * @Assert\NotNull
     * @Assert\Type(type = "int")
     * @Assert\GreaterThanOrEqual(0)
     */
    protected $maxWidth;

    /**
     * @Assert\NotNull
     * @Assert\Type(type = "int")
     * @Assert\GreaterThanOrEqual(0)
     */
    protected $maxHeight;

    /**
     * @Assert\NotNull
     * @Assert\Type(type = "int")
     * @Assert\Range(
     *     min = 1,
     *     max = 100
     * )
     */
    protected $jpgCompressionLevel;


    public function __construct()
    {
        try {
            $settings = Plugin::getInstance()->getImageProcessingSettings();

            $this->setEnableResizing( $settings->resizingEnabled );
            $this->setMaxWidth( $settings->maxWidth );
            $this->setMaxHeight( $settings->maxHeight );
            $this->setJpgCompressionLevel( $settings->jpgCompressionLevel );
        } catch ( \Exception $e ) { }
    }


    public function getEnableResizing()
    {
        return $this->enableResizing;
    }

    public function setEnableResizing($enable)
    {
        $this->enableResizing = $enable;
    }


    public function getMaxWidth()
    {
        return $this->maxWidth;
    }

    public function setMaxWidth($maxWidth)
    {
        $this->maxWidth = $maxWidth;
    }


    public function getMaxHeight()
    {
        return $this->maxHeight;
    }

    public function setMaxHeight($maxHeight)
    {
        $this->maxHeight = $maxHeight;
    }


    public function getJpgCompressionLevel()
    {
        return $this->jpgCompressionLevel;
    }

    public function setJpgCompressionLevel($level)
    {
        $this->jpgCompressionLevel = $level;
    }


    public function save()
    {
        $settings = Plugin::getInstance()->getImageProcessingSettings();

        $settings->resizingEnabled = $this->getEnableResizing();
        $settings->maxWidth = $this->getMaxWidth();
        $settings->maxHeight = $this->getMaxHeight();
        $settings->jpgCompressionLevel = $this->getJpgCompressionLevel();
    }
}
