<?php

namespace EasyContent\WordPress\Forms\Entities;

use EasyContent\WordPress\Db\Models\WorkflowStage;
use EasyContent\WordPress\Pages\Import\Importer;
use EasyContent\WordPress\Plugin;
use Symfony\Component\Validator\Constraints as Assert;
use EasyContent\WordPress\Forms\Constraints as AssertApp;

class ImportEntity
{
    /**
     * @Assert\GreaterThanOrEqual(1)
     * @AssertApp\WorkflowStageExists
     */
    protected $newStage;

    /**
     * @Assert\NotBlank
     */
    protected $articleIds = [];


    public function getNewStage()
    {
        return $this->newStage;
    }

    public function setNewStage($id)
    {
        $this->newStage = $id;
    }


    public function getArticleIds()
    {
        return array_unique( array_values( $this->articleIds ) );
    }

    public function setArticleIds(array $ids)
    {
        $this->articleIds = $ids;
    }


    public function process()
    {
        $newWorkflowStage = null;

        if ( $this->getNewStage() ) {
            try {
                $newWorkflowStage = WorkflowStage::findByKey( $this->getNewStage() );
            } catch ( \Exception $e ) {
                Plugin::getInstance()->noticesManager->addNotice( 'Unable to find workflow stage', 'error' );
                return false;
            }
        }

        $importer = new Importer();
        return $importer->run( $this->getArticleIds(), $newWorkflowStage );
    }
}
