<?php

namespace EasyContent\WordPress\Forms\Validators;

use EasyContent\WordPress\Forms\Constraints\ApiKeysWereChanged;
use EasyContent\WordPress\Forms\Entities\ApiKeys;
use EasyContent\WordPress\Plugin;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;
use Symfony\Component\Validator\Exception\UnexpectedTypeException;

class ApiKeysWereChangedValidator extends ConstraintValidator
{
    /**
     * @param ApiKeys $keys
     * @param ApiKeysWereChanged $constraint
     */
    public function validate($keys, Constraint $constraint)
    {
        if ( ! $constraint instanceof ApiKeysWereChanged ) {
            throw new UnexpectedTypeException( $constraint, ApiKeysWereChanged::class );
        }

        if ( ! $keys instanceof ApiKeys ) {
            throw new UnexpectedTypeException( $keys, ApiKeys::class );
        }

        // custom constraints should ignore null and empty values to allow
        // other constraints (NotBlank, NotNull, etc.) take care of that
        if ( null === $keys->getPublic() || '' === $keys->getPublic() ) {
            return;
        }

        $settings = Plugin::getInstance()->getSettings();

        if ( $settings->publicKey === $keys->getPublic() ) {
            if ( $settings->isPluginConnected ) {
                $this->context->buildViolation( $constraint->alreadyInUseMessage )->addViolation();
                return;
            }

            $this->context->buildViolation( $constraint->invalidKeysMessage )->addViolation();
        }
    }
}
