<?php

namespace EasyContent\WordPress\Forms\Validators;

use EasyContent\WordPress\Forms\Constraints\PostCategoryExists;
use Symfony\Component\Form\Exception\UnexpectedTypeException;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;

class PostCategoryExistsValidator extends ConstraintValidator
{
    public function validate($value, Constraint $constraint)
    {
        if ( ! $constraint instanceof PostCategoryExists ) {
            throw new UnexpectedTypeException( $constraint, PostCategoryExists::class );
        }

        // custom constraints should ignore null and empty values to allow
        // other constraints (NotBlank, NotNull, etc.) take care of that
        if ( null === $value || '' === $value ) {
            return;
        }

        $category = get_category( $value );

        if ( ! $category || is_wp_error( $category ) ) {
            $this->context->buildViolation( $constraint->message )->addViolation();
        }
    }
}
