<?php

namespace EasyContent\WordPress\Forms\Validators;

use EasyContent\WordPress\Forms\Constraints\WordPressUserExists;
use Symfony\Component\Form\Exception\UnexpectedTypeException;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;

class WordPressUserExistsValidator extends ConstraintValidator
{
    public function validate($userId, Constraint $constraint)
    {
        if ( ! $constraint instanceof WordPressUserExists ) {
            throw new UnexpectedTypeException( $constraint, WordPressUserExists::class );
        }

        // custom constraints should ignore null and empty values to allow
        // other constraints (NotBlank, NotNull, etc.) take care of that
        if ( null === $userId || '' === $userId ) {
            return;
        }

        if ( $userId == 0 ) {
            return;
        }

        $user = get_user_by( 'id', $userId );

        if ( ! $user ) {
            $this->context->buildViolation( $constraint->message )->addViolation();
        }
    }
}
