<?php

namespace EasyContent\WordPress\Helpers;

use EasyContent\WordPress\Plugin;

class CategoriesMapper
{
    /**
     * This method is used when importing article to WordPress.
     *
     * @param int[] $categories EasyContent topic's category ids array
     * @return int[] Ids of categories that new post must be in.
     * @throws \Exception
     */
    public static function getWpCategoriesIds($categories)
    {
        $termIds = [];
        $settings = Plugin::getInstance()->getSettings();
        $flippedCategories = array_flip( $categories );

        foreach ( $settings->mappings as $termId => $easyContentCategoryId ) {
            if ( ! isset( $flippedCategories[$easyContentCategoryId] ) ) {
                continue;
            }

            $termIds[] = $termId;
        }

        if ( ! $termIds ) {
            $termIds = [$settings->defaultCategoryId];
        }

        return array_unique( $termIds );
    }


    /**
     * @param \WP_Post $post
     * @return array|int[]
     * @throws \Exception
     */
    public static function getRelatedCategoriesList(\WP_Post $post)
    {
        $categoriesIds = wp_get_post_categories( $post->ID, ['fields' => 'ids'] );

        if ( ! $categoriesIds || is_wp_error( $categoriesIds ) ) {
            return [];
        }

        $ecCategoriesIds = [];
        $mappings = Plugin::getInstance()->getSettings()->mappings;

        foreach ( $categoriesIds as $termId ) {
            if ( (int)$mappings[$termId] > 0 ) {
                $ecCategoriesIds[] = (int)$mappings[$termId];
            }
        }

        return $ecCategoriesIds;
    }
}
