<?php

namespace EasyContent\WordPress\Pages;

use EasyContent\WordPress\Plugin;

final class PagesManager
{
    private $_renderCallback;


    public function __construct(callable $renderCallback)
    {
        $this->_renderCallback = $renderCallback;

        add_action( 'admin_menu', [$this, 'addMenuPages'], 1000 );
    }


    public function addMenuPages()
    {
        $plugin = Plugin::getInstance();

        add_menu_page(
            __( 'EasyContent', EASYCONTENT_TXTDOMAIN ),
            __( 'EasyContent', EASYCONTENT_TXTDOMAIN ),
            'activate_plugins',
            'easycontent-index',
            function() { }, // This page will never be shown
            'dashicons-networking',
            77
        );

        add_submenu_page(
            'easycontent-index',
            __( 'EasyContent', EASYCONTENT_TXTDOMAIN ),
            __( 'EasyContent connection', EASYCONTENT_TXTDOMAIN ),
            'activate_plugins',
            'easycontent-connection',
            $this->_renderCallback
        );

//        add_submenu_page(
//            'easycontent-index',
//            __( 'Database', EASYCONTENT_TXTDOMAIN ), // TODO
//            __( 'Database', EASYCONTENT_TXTDOMAIN ), // TODO
//            'activate_plugins',
//            'easycontent-database',
//            [new Database( 'database' ), 'render']
//        );

        if ( $plugin->getSettings()->isPluginConnected ) {
            add_submenu_page(
                'easycontent-index',
                __( 'Publishing options', EASYCONTENT_TXTDOMAIN ),
                __( 'Publishing options', EASYCONTENT_TXTDOMAIN ),
                'activate_plugins',
                'easycontent-publishing-options',
                $this->_renderCallback
            );

            add_submenu_page(
                'easycontent-index',
                __( 'SEO settings', EASYCONTENT_TXTDOMAIN ),
                __( 'SEO settings', EASYCONTENT_TXTDOMAIN ),
                'activate_plugins',
                'easycontent-seo',
                $this->_renderCallback
            );

            add_submenu_page(
                'easycontent-index',
                __( 'Image processing', EASYCONTENT_TXTDOMAIN ),
                __( 'Image processing', EASYCONTENT_TXTDOMAIN ),
                'activate_plugins',
                'easycontent-image-processing',
                $this->_renderCallback
            );

            add_submenu_page(
                'easycontent-index',
                __( 'Import from EasyContent', EASYCONTENT_TXTDOMAIN ),
                __( 'Import from EasyContent', EASYCONTENT_TXTDOMAIN ),
                'activate_plugins',
                'easycontent-import',
                $this->_renderCallback
            );
        }

        // Must be always at the end of the method
        remove_submenu_page( 'easycontent-index', 'easycontent-index' );
    }
}
