<?php

namespace EasyContent\WordPress\Rest\Actions;

use EasyContent\WordPress\Db\Models\WorkflowStage;
use EasyContent\WordPress\Helpers\ArticleWorkflowStageUpdater;
use EasyContent\WordPress\Plugin;
use EasyContent\WordPress\Post;

class SetArticleWorkflowStage extends BaseAction
{
    protected $methods = ['PATCH'];


    public function getArgumentsConfig()
    {
        return [
            'post_id' => [
                'type'              => 'integer',
                'required'          => true,
                'sanitize_callback' => 'absint'
            ]
        ];
    }


    public function run(\WP_REST_Request $request)
    {
        $plugin = Plugin::getInstance();

        $plugin->log( 'Changing article\'s workflow stage with WP Rest API' );

        try {
            $post = new Post( (int)$request['post_id'] );

            $body = (string)$request->get_body();
            $body = '' === $body ? [] : json_decode( $body, true );

            $workflowStageId = isset( $body['workflow_stage_id'] ) ? (int)$body['workflow_stage_id'] : 0;

            if ( $workflowStageId <= 0 ) {
                throw new \Exception( __( 'Invalid workflow stage ID', EASYCONTENT_TXTDOMAIN ), 15 );
            }

            $relatedArticle = $post->getArticle();
            if ( ! $relatedArticle ) {
                throw new \Exception( __( 'This post was not synchronized yet', EASYCONTENT_TXTDOMAIN ), 16 );
            }

            $currentWorkflowStage = $relatedArticle->getCurrentWorkflowStage();
            if ( ! $currentWorkflowStage ) {
                throw new \Exception( __( 'Data misconfiguration', EASYCONTENT_TXTDOMAIN ), 17 );
            }

            if ( $currentWorkflowStage->id == $workflowStageId ) {
                $plugin->log( 'Workflow stage ID was not changed. Returning...' );

                return null;
            }

            $workflowStage = WorkflowStage::findByKey( $workflowStageId );
            if ( ! $workflowStage ) {
                throw new \Exception( __( 'This workflow stage does not exist', EASYCONTENT_TXTDOMAIN ), 18 );
            }

            return ( new ArticleWorkflowStageUpdater() )->update( $post, $workflowStageId );
        } catch (\Exception $e) {
            $plugin->log( 'Error during setting new article workflow stage: ' . $e->getMessage() );

            return new \WP_Error( $e->getCode(), $e->getMessage() );
        }
    }
}
