<?php
/**
 * @var EasyContent\WordPress\View $this
 * @var bool $isConnected
 * @var Symfony\Component\Form\FormView $formView
 * @var string $accountName
 * @var string $projectName
 * @var string $projectUrl
 * @var null|string $referer
 */
?>
<div class="wrap">
    <h1><?= esc_html( get_admin_page_title() ) ?></h1>

    <?php if ( $isConnected ) : ?>
        <h2 class="ec-header ec-header_green">
            You have successfully connected to <a href="<?= esc_url( $projectUrl ) ?>" target="_blank">
            <?= esc_html( $projectName ) ?></a> project in your "<?= esc_html( $accountName ) ?>" account.
        </h2>
    <?php endif ?>

    <?php $this->renderGlobalNotices() ?>

    <?php if ( ! $isConnected ) : ?>
        <p>
            <?= esc_html__( 'Set up your connection with EasyContent. You can find the instructions', EASYCONTENT_TXTDOMAIN ) ?>
            <a href="https://easycontent.io/help-article/wordpress-integration">
                <?= esc_html__( 'here', EASYCONTENT_TXTDOMAIN ) ?>
            </a>.
        </p>
    <?php endif ?>

    <form method="<?= esc_attr( $formView->vars['method'] ) ?>" novalidate="novalidate">
        <table class="form-table">
            <tbody>
                <tr>
                    <th scope="row">
                        <label for="<?= esc_attr( $formView['public']->vars['id'] ) ?>">
                            <?= esc_html__( 'API Key', EASYCONTENT_TXTDOMAIN ) ?>
                        </label>
                    </th>
                    <td>
                        <input
                            type="text"
                            class="regular-text"
                            name="<?= esc_attr( $formView['public']->vars['full_name'] ) ?>"
                            id="<?= esc_attr( $formView['public']->vars['id'] ) ?>"
                            value="<?= esc_attr( $formView['public']->vars['value'] ) ?>">

                        <?php if ( ! $formView['public']->vars['valid'] ) : ?>
                            <?php foreach ( $formView['public']->vars['errors'] as $error ) :
                                /** @var Symfony\Component\Form\FormError $error */ ?>
                                <p style="color: red;"><?= esc_html( $error->getMessage() ) ?></p>
                            <?php endforeach ?>
                        <?php endif ?>
                    </td>
                </tr>
                <tr>
                    <th scope="row">
                        <label for="msar-url-input">
                            <?= esc_html__( 'Current site URL', EASYCONTENT_TXTDOMAIN ) ?>
                        </label>
                    </th>
                    <td>
                        <?php if ( $referer ) : ?>
                            <span id="msar-url-wrapper">
                                <?= esc_html( $referer ) ?>
                                <a href="#" id="msar-change-url-button">
                                    <?= esc_html__( 'Change', EASYCONTENT_TXTDOMAIN ) ?>
                                </a>
                            </span>
                        <?php endif ?>

                        <input
                            id="msar-url-input"
                            class="regular-text"
                            name="<?= esc_attr( $formView['url']->vars['full_name'] ) ?>"
                            type="<?= esc_attr( $referer ? 'hidden' : 'text' ) ?>"
                            value="<?= esc_attr( $referer ?: '' ) ?>"
                            placeholder="<?= esc_attr__( 'Please enter current site URL', EASYCONTENT_TXTDOMAIN ) ?>">

                        <?php if ( ! $formView['url']->vars['valid'] ) : ?>
                            <?php foreach ( $formView['url']->vars['errors'] as $error ) :
                                /** @var Symfony\Component\Form\FormError $error */ ?>
                                <p style="color: red;"><?= esc_html( $error->getMessage() ) ?></p>
                            <?php endforeach ?>
                        <?php endif ?>

                        <p class="description" id="tagline-ec-private-api-key">
                            <a href="https://easycontent.io/help-article/wordpress-integration">
                                <?= esc_html__( 'How to get your API key?', EASYCONTENT_TXTDOMAIN ) ?>
                            </a>
                        </p>
                    </td>
                </tr>
            </tbody>
        </table>

        <p class="submit">
            <input type="submit" name="" id="submit" class="button button-primary" value="<?= esc_attr__( 'Save Changes', EASYCONTENT_TXTDOMAIN ) ?>">
            <?php if ( $isConnected ) : ?>
                <a href="<?= admin_url( 'admin.php?page=easycontent-publishing-options' ) ?>" class="button">
                    <?= esc_html__( 'Proceed to publishing options', EASYCONTENT_TXTDOMAIN ) ?>
                </a>
            <?php endif ?>
        </p>
    </form>
</div>

<script type="application/javascript">
    (function($) {
        $(document).ready(function() {
            $('#msar-change-url-button').click(function(e) {
                e.preventDefault();

                $('#msar-url-wrapper').hide();
                $('#msar-url-input').attr('type', 'text');
            });
        });
    })(jQuery);
</script>
