<?php
/**
 * @var EasyContent\WordPress\View $this
 * @var EasyContent\WordPress\Pages\Import\ArticlesListTable $table
 * @var array $workflowStages
 * @var Symfony\Component\Form\FormView $searchFormView
 */

use EasyContent\WordPress\Db\Models\WorkflowStage;
use EasyContent\WordPress\View;

?>
<div class="wrap">
    <h1 class="wp-heading-inline"><?= esc_html__( 'Import articles from EasyContent.io', EASYCONTENT_TXTDOMAIN ) ?></h1>

    <form action="<?= admin_url( 'admin.php?page=easycontent-import' ) ?>" method="post" class="ec-header-form">
        <button type="submit" name="action" value="refresh-all" class="button-primary button-large page-title-action">
            <?= esc_html__( 'Refresh all data', EASYCONTENT_TXTDOMAIN ) ?>
        </button>
    </form>

    <hr class="wp-header-end">

    <?php
        $this->renderGlobalNotices();

        echo (new View())->render( 'admin/pages/import/table-filters', [
            'stages' => WorkflowStage::getFilterData(),
            'searchFormView' => $searchFormView
        ] );
    ?>

    <form action="<?= admin_url( 'admin.php?page=easycontent-import' ) ?>" method="post">
        <input type="hidden" name="page" value="easycontent-import">

        <div class="import-selected">
            <button class="button button-primary button-large" type="submit" name="ECImportArticlesForm[run]" value="top">
                <?= esc_html__( 'Import selected items', EASYCONTENT_TXTDOMAIN ) ?>
            </button>

            <?php if ( $workflowStages ) : ?>
                <?= esc_html__( 'On import, change EasyContent status to', EASYCONTENT_TXTDOMAIN ) ?>

                <select name="ECImportArticlesForm[top][newStage]">
                    <option value=""><?= esc_html__( "Don't change status", EASYCONTENT_TXTDOMAIN ) ?></option>

                    <?php foreach ( $workflowStages as $stage ) : ?>
                        <option value="<?= esc_attr( $stage['id'] ) ?>">
                            <?= esc_html( $stage['name'] ) ?>
                        </option>
                    <?php endforeach ?>
                </select>
            <?php endif ?>
        </div>

        <?php $table->display() ?>

        <div class="import-selected">
            <button class="button button-primary button-large" type="submit" name="ECImportArticlesForm[run]" value="bottom">
                <?= esc_html__( 'Import selected items', EASYCONTENT_TXTDOMAIN ) ?>
            </button>

            <?php if ( $workflowStages ) : ?>
                <?= esc_html__( 'On import, change EasyContent status to', EASYCONTENT_TXTDOMAIN ) ?>

                <select name="ECImportArticlesForm[bottom][newStage]">
                    <option value=""><?= esc_html__( "Don't change status", EASYCONTENT_TXTDOMAIN ) ?></option>

                    <?php foreach ( $workflowStages as $stage ) : ?>
                        <option value="<?= esc_attr( $stage['id'] ) ?>">
                            <?= esc_html( $stage['name'] ) ?>
                        </option>
                    <?php endforeach ?>
                </select>
            <?php endif ?>
        </div>
    </form>
</div>
